# Generated by roxygen2: do not edit by hand

S3method(coef,orthoMTL)
S3method(predict,orthoMTL)
S3method(print,bootstrap_orthoMTL)
S3method(print,cv_orthoMTL)
S3method(print,orthoMTL)
S3method(print,simulated_mtl)
S3method(summary,orthoMTL)
export(accuracy_mtl)
export(auc_mtl)
export(bootstrap_orthoMTL)
export(cindex_mtl)
export(create_constraint_matrix)
export(create_indicator_matrix)
export(create_longitudinal_labels)
export(cv_orthoMTL)
export(nnmaxheap_C)
export(orthoMTL)
export(plot_bootstrap)
export(plot_correlation)
export(plot_heatmap)
export(plot_prediction)
export(r2_mtl)
export(rmse_mtl)
export(simulate_mtl)
importFrom(doParallel,registerDoParallel)
importFrom(foreach,"%dopar%")
importFrom(foreach,foreach)
importFrom(ggplot2,aes)
importFrom(parallel,makeCluster)
importFrom(parallel,stopCluster)
importFrom(rlang,.data)
importFrom(stats,coef)
importFrom(stats,median)
importFrom(stats,predict)
importFrom(stats,rbeta)
importFrom(stats,rbinom)
importFrom(stats,rexp)
importFrom(stats,rnorm)
importFrom(stats,runif)
