% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/proj_disjoint.R
\name{proj_disjoint}
\alias{proj_disjoint}
\title{Projection onto Disjoint Support Feasible Set}
\usage{
proj_disjoint(w, v)
}
\arguments{
\item{w}{Numeric matrix of weights used in the loss function.}

\item{v}{Numeric matrix of constraints used for projection.}
}
\value{
A list with projected matrices \code{w} and \code{v}.
}
\description{
Projects weight and constraint matrices ...
}
\keyword{internal}
