% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bootstrap_print.R
\name{print.bootstrap_orthoMTL}
\alias{print.bootstrap_orthoMTL}
\title{Print Bootstrap Inference Results}
\usage{
\method{print}{bootstrap_orthoMTL}(x, ...)
}
\arguments{
\item{x}{An object of class \code{"bootstrap_orthoMTL"}.}

\item{...}{Additional arguments (currently ignored).}
}
\value{
Invisibly returns \code{x}.
}
\description{
Displays a summary of bootstrap inference results from
\code{\link{bootstrap_orthoMTL}}.
}
\examples{
# See ?bootstrap_orthoMTL for a full example
}
